let programs = {}
const days = ['ראשון', 'שני', 'שלישי', 'רביעי', 'חמישי', 'שישי', 'שבת']

const ZOOM_DATES = [[4, 3], [11, 3], [25, 3], [1, 4], [8, 4]]
const ZOOM_TIMES_INTERVAL = 10
const ZOOM_TIMES_MIN_MAX = [10, 12]
const ZOOM_MEETINGS_PER_HOUR = 4
const ZOOM_MEETINGS_PER_DAY = 48; // 4 meetings / slot X 12 meeting slots / day

const PHYSICAL_DATES = [[5, 3], [12, 3], [19, 3], [26, 3], [2, 4], [9, 4]]
const PHYSICAL_TIMES_INTERVAL = 60
const PHYSICAL_TIMES_MIN_MAX = [10, 13]
const PHYSICAL_MEETINGS_PER_HOUR = 14
const PHYSICAL_MEETINGS_PER_DAY = 42; // 14 meetings / slot X 3 meeting slots /day 

let current_dates = ZOOM_DATES
let current_interval = ZOOM_TIMES_INTERVAL
let current_min_max = ZOOM_TIMES_MIN_MAX
let current_meetings_per_hour = ZOOM_MEETINGS_PER_HOUR
let current_meetings_per_day = ZOOM_MEETINGS_PER_DAY

function hideAll() {
    $('#meetingDate').parent().hide();
    $('#meetingTime').parent().hide();
    $('#degreeSelect').parent().show();
    // $('#fieldSelect').parent().hide();
    $('#programSelect').parent().hide();
}
function showPhysical() {
    current_dates = PHYSICAL_DATES
    current_interval = PHYSICAL_TIMES_INTERVAL
    current_min_max = PHYSICAL_TIMES_MIN_MAX
    current_meetings_per_hour = PHYSICAL_MEETINGS_PER_HOUR
    current_meetings_per_day = PHYSICAL_MEETINGS_PER_DAY
    $('#meetingDate').parent().show();
    $('#meetingTime').parent().hide();
    $('#fieldSelect').parent().show();
    $('#programSelect').parent().show();
    // $('#degreeSelect option[value="1"]').hide();
}
function showPhone() {
    $('#fieldSelect').parent().show();
    $('#programSelect').parent().show();
    $('#degreeSelect').parent().show();
	$('#myform').attr('action','https://www.leadock.com/pages/formHandler');
    // $('#degreeSelect option[value="1"]').show();
}
function showZoom() {
    current_dates = ZOOM_DATES
    current_interval = ZOOM_TIMES_INTERVAL
    current_min_max = ZOOM_TIMES_MIN_MAX
    current_meetings_per_hour = ZOOM_MEETINGS_PER_HOUR
    current_meetings_per_day = ZOOM_MEETINGS_PER_DAY
    $('#meetingDate').parent().show();
    $('#meetingTime').parent().hide();
    $('#fieldSelect').parent().show();
    $('#programSelect').parent().show();
    // $('#degreeSelect option[value="1"]').hide();
}

function addZero(a) {
    return a < 10 ? `0${a}` : a;
}
function populateDates(dates) {
    if (meetingData.length <= 0) {
        var parsedData = {};
    } else {
        var parsedData = JSON.parse(meetingData);
    }
    
    $("#meetingDate").empty().append($('<option>', {
        value: '',
        text: 'תאריך מפגש:',
    }));

    var newData = {}
    for (let [date, times] of Object.entries(parsedData)) {
        if (!newData[date])
            newData[date] = 0
        for (let count of Object.values(times))
            newData[date] += count
    }
    for (let [day, month] of dates) {
        const d = new Date(2024, month - 1, day, current_min_max[0])
        const dateString = `${d.getDate()}.${d.getMonth() + 1}.${d.getFullYear() - 2000}`
        $("#meetingDate").append($('<option>', {
            // value: `${d.getFullYear()}`,
            value: dateString,
            text: `יום ${days[d.getDay()]} ה- ${d.getDate()}.${d.getMonth() + 1}.${d.getFullYear() - 2000}`,
            disabled: newData[dateString] >= current_meetings_per_day? true: false
        }))
    }
}
function populateTimes(interval, selectedDate, meetingData) {
    if (meetingData.length <= 0) {
        var parsedData = undefined;
    } else {
        var parsedData = JSON.parse(meetingData);
    }
    $("#meetingTime").empty().append($('<option>', {
        value: '',
        text: 'שעת מפגש:',
    }));
    for (let i = current_min_max[0]; i < current_min_max[1]; i++) {
        for (let j = 0; j < 60; j += interval) {
            const d = new Date(2024, 1, 1, i, j, 0);
            let end = new Date(d);
            end.setMinutes(end.getMinutes() + interval);
            // Construct the time string with flipped hours for display
            const timeDisplay = `${addZero(end.getHours())}:${addZero(end.getMinutes())}-${d.getHours()}:${addZero(d.getMinutes())}`;
            // Keep the value logical for backend processing
            const timeValue = `${d.getHours()}:${addZero(d.getMinutes())}-${end.getHours()}:${addZero(end.getMinutes())}`;
            $("#meetingTime").append($('<option>', {
                value: timeValue, // Use logical order here for processing
                text: timeDisplay, // Display flipped times to the user
                disabled: (parsedData[selectedDate] && parsedData[selectedDate][timeValue] >= current_meetings_per_hour)? true: false
            }))
        }
    }
}

function populateSelect(selectId, options, selected = '') {
    const select = $(selectId);
    // Remove all options except the first one
    select.find('option:not(:first)').remove();
    Object.entries(options).forEach(([key, value]) => {
        select.append($('<option>', {
            value: key,
            text: value.label
        }));
    });
    select.val(selected).trigger('change');
    if (selected != '')
        select.parent().hide();
}

function onChangeDegree() {
    var selectedValue = $('#degreeSelect').val();
    $('#fieldSelect').parent().hide();
    $('#programSelect').parent().hide();

    if (selectedValue) {
        if (programs[selectedValue] && programs[selectedValue].childs) {
            populateSelect('#fieldSelect', programs[selectedValue].childs);
            $('#fieldSelect').parent().show();
            $('input[name="268"]').val(programs[selectedValue]['label']);
            $('input[name="269"]').val(selectedValue);
        }
    }
    $('#programSelect').parent().hide();
}
function onChangeField() {
    var degreeSelectValue = $('#degreeSelect').val();
    var selectedValue = $(this).val();
    $('#programSelect').parent().hide();
    if (degreeSelectValue && selectedValue) {
        if (programs[degreeSelectValue].childs[selectedValue] && programs[degreeSelectValue].childs[selectedValue].childs) {
            populateSelect('#programSelect', programs[degreeSelectValue].childs[selectedValue].childs);
            $('#programSelect').parent().show();
            $('input[name="270"]').val(programs[degreeSelectValue].childs[selectedValue]['label']);
            $('input[name="271"]').val(programs[degreeSelectValue].childs[selectedValue]['value']);
        }
    }
}
function onChangeProgram() {
    var degreeSelectValue = $('#degreeSelect').val();
    var fieldSelectValue = $('#fieldSelect').val();
    var selectedValue = $(this).val();
    if (selectedValue) {
        var field_value = programs[degreeSelectValue].childs[fieldSelectValue].childs[selectedValue];
        if (programs[degreeSelectValue].childs[fieldSelectValue].childs[selectedValue]) {
            $('input[name="272"]').val(field_value['label']);
            $('input[name="273"]').val(field_value['value']);
        }
    }
}
async function onChangeMain() {
    programs = await $.getJSON('data/programs.json');
    // Show the form and hide the mainSelect dropdown
    $('#myform').show();
    const mainSelect = $(this);
    mainSelect.closest('fieldset').hide(); // Adjust this if mainSelect is not within a fieldset
    const selected = mainSelect.val();
    // Show the "change selection" button
    $('#changeSelection').show();

    hideAll();
    // Logic for showing fields based on selection
    if (selected === 'phone_advice') {
        showPhone();
        populateSelect('#degreeSelect', programs, '');
    } else {
        if (selected === 'zoom_meeting')
            showZoom();
        else
            showPhysical();
        $('#meetingDate').prop('required', true)
        $('#meetingTime').prop('required', true)
        populateSelect('#degreeSelect', programs, 1);
        onChangeDegree();
        populateDates(current_dates);
    }

}
$(document).ready(function () {
    hideAll();
    $('#degreeSelect').change(onChangeDegree);
    $('#fieldSelect').change(onChangeField);
    $('#programSelect').change(onChangeProgram);
    $('#mainSelect').change(onChangeMain);

    $('#meetingDate').change(function () {
        $('#meetingTime').parent().show();
        var selectedDate = $(this).val();
        populateTimes(current_interval, selectedDate, meetingData)
    });
    $('#changeSelection').click(function () {
        location.reload();
    });
});



setInterval(function () {
    document.getElementById("field_281").value = document.getElementById("meetingDate").value;
    document.getElementById("field_282").value = document.getElementById("meetingTime").value;;
    document.getElementById("field_283").value = document.getElementById("mainSelect").value;;
}, 100);
